# Changelog

## 0.4.0 (2026-01-26)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/Labric-Platforms/labric-py/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([b11baa2](https://github.com/Labric-Platforms/labric-py/commit/b11baa2a35cefaccd2f16b52d3aa937097fcd5fd))
* **client:** add support for binary request streaming ([44399ac](https://github.com/Labric-Platforms/labric-py/commit/44399ac7993827da4e225f5f766af29e60ab7e7f))


### Bug Fixes

* **client:** loosen auth header validation ([5a632eb](https://github.com/Labric-Platforms/labric-py/commit/5a632ebdf7a8e5700447bbff8aeddec3426e8968))
* ensure streams are always closed ([1e20dca](https://github.com/Labric-Platforms/labric-py/commit/1e20dca587d1dbf9a764235d2c060997cadc66b2))
* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([6fdde9d](https://github.com/Labric-Platforms/labric-py/commit/6fdde9d5b660c13ddc99c60040d076f363bd8f89))
* use async_to_httpx_files in patch method ([dca0882](https://github.com/Labric-Platforms/labric-py/commit/dca08823c2d215f44b51c86da84680cff65243b2))


### Chores

* **ci:** upgrade `actions/github-script` ([ac8b361](https://github.com/Labric-Platforms/labric-py/commit/ac8b361595211a49992ea95be9d10cd6fe714f98))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([93240c9](https://github.com/Labric-Platforms/labric-py/commit/93240c968eae15abe1f213133da471ce6c8dff9f))
* **docs:** use environment variables for authentication in code snippets ([446e457](https://github.com/Labric-Platforms/labric-py/commit/446e457866bab9f1315184613c031eaf3ca3a889))
* **internal:** add `--fix` argument to lint script ([23cd05b](https://github.com/Labric-Platforms/labric-py/commit/23cd05bf9dd139315d38a04e9b0daa37f325c595))
* **internal:** add missing files argument to base client ([e646312](https://github.com/Labric-Platforms/labric-py/commit/e646312770d61e4721e96ce1894319de92be47d8))
* **internal:** codegen related update ([84dc12e](https://github.com/Labric-Platforms/labric-py/commit/84dc12e90dfa23b9e00880cc870d856288737d9e))
* **internal:** update `actions/checkout` version ([9a6a2d0](https://github.com/Labric-Platforms/labric-py/commit/9a6a2d0bb950c699d129825d613381b93d4ab157))
* speedup initial import ([6c0acd9](https://github.com/Labric-Platforms/labric-py/commit/6c0acd98146173e04a5fa4be7d9424a74d6baa0c))
* update lockfile ([9e82340](https://github.com/Labric-Platforms/labric-py/commit/9e823408643e79c39dbaf5391d0d2404c8c3d03f))


### Refactors

* **internal:** switch from rye to uv ([ac76d78](https://github.com/Labric-Platforms/labric-py/commit/ac76d783c4678bbc8820d502ae9fe61823c57c52))

## 0.3.0 (2025-11-25)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Labric-Platforms/labric-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([f82d9a6](https://github.com/Labric-Platforms/labric-py/commit/f82d9a653c7b4da9f6196725a88be6a3628ecb8c))

## 0.2.0 (2025-11-24)

Full Changelog: [v0.1.2...v0.2.0](https://github.com/Labric-Platforms/labric-py/compare/v0.1.2...v0.2.0)

### Features

* **api:** manual updates ([e0f4f03](https://github.com/Labric-Platforms/labric-py/commit/e0f4f03f622242048d0addbf3b1434ce63100049))
* **api:** manual updates ([5acb6aa](https://github.com/Labric-Platforms/labric-py/commit/5acb6aaba9518172d3e5f4fb479302a04689a5f2))
* **api:** manual updates ([1b1bde4](https://github.com/Labric-Platforms/labric-py/commit/1b1bde488e36983d08937cc0ca6c02b957f2f856))
* **api:** manual updates ([d56db38](https://github.com/Labric-Platforms/labric-py/commit/d56db38e7191a662139e772883b920efc8268ec0))


### Chores

* add Python 3.14 classifier and testing ([910b8bd](https://github.com/Labric-Platforms/labric-py/commit/910b8bd108590943d51b33b70c61a3f1805e5b34))
* update SDK settings ([331e4e0](https://github.com/Labric-Platforms/labric-py/commit/331e4e05e34a80ed395e15f6c1cc643772ffc373))
* update SDK settings ([3392a6b](https://github.com/Labric-Platforms/labric-py/commit/3392a6bbf0a21d0107a3118565689d1ae31260d9))

## 0.1.2 (2025-11-20)

Full Changelog: [v0.0.1...v0.1.2](https://github.com/Labric-Platforms/labric-py/compare/v0.0.1...v0.1.2)

### Features

* **api:** manual updates ([65fce15](https://github.com/Labric-Platforms/labric-py/commit/65fce1566dd07af74758724750c15decab7bbc3f))
* **api:** manual updates ([5af17b8](https://github.com/Labric-Platforms/labric-py/commit/5af17b8aab9f830eba30e4fe906995efb0dbfca7))
* **api:** manual updates ([60f6d0f](https://github.com/Labric-Platforms/labric-py/commit/60f6d0f1c6ea343679f3239fb5ed39538ebc3870))


### Chores

* update SDK settings ([5f744c8](https://github.com/Labric-Platforms/labric-py/commit/5f744c899190b43849ff945c1d7862ee9c2a048d))
* update SDK settings ([0d08652](https://github.com/Labric-Platforms/labric-py/commit/0d086520f88b45676ea88676169bbf65df5ad29a))
